class LogsController < ApplicationController
  layout :set_layout
  FILTERED_PAGE_SIZE = 50
  ZOOM_PAGE_SIZE = 30
  LIVE_VIEW = 1

  def index
    session[:lines] = []
    @tags = FilterTag.find_all_by_filter_type(filter_type, :conditions=>{:predefined=>false}, :order=> "id desc")
    
    create_logdb(params)

    respond_to do |format|
      format.html 
      format.xml
    end
  end
  
  def show
    session[:lines] = SyslogLive.get_current_logs(params)
    render :partial => 'log_lines'
  end
    
  def page_newer
    session[:lines] = session[:logdb].find_newer
    render :partial => 'log_lines'
  end
  
  def page_older
    session[:lines] = session[:logdb].find_older
    render :partial => 'log_lines'
  end
 
  def page_newest
    session[:lines] = session[:logdb].find_newest
    render :partial => 'log_lines'
  end
  
  def page_oldest
    session[:lines] = session[:logdb].find_oldest
    render :partial => 'log_lines'
  end
    
  
  def load_filter
    create_logdb(params)
    render :partial => 'log_lines'
  end
  
  def load_saved_filter
    create_logdb(params, true)
    render :partial => 'log_lines'
  end

  def manage_filters
   check_is_admin
   @tags = FilterTag.find_all_by_filter_type(filter_type, :conditions=>{:predefined=>false}, :order=> "id desc")
    render :partial => 'includes/logs/saved_filters'
  end
    
  def get_pagination
    @page_num = params[:page_num].to_i
    @filter_displayed = params[:filter_displayed] 
    render :partial => 'pages'
  end
 
  def get_disabled_pagination
    @filter_displayed = params[:filter_displayed] 
    @page_num         = 1
    render :partial => 'disabled_pages'
  end

  def set_layout
    ajax? ? false : "application"
  end
  
  protected
  def log_db
  end
  
  private 
  def create_logdb(filter_params, stored=false)
  #After instantiating a new LmiFilter object for Alerts
  #the filters are accessible in the 'filters' attribute
  #ex: params = {"filter"=>{"criteria_1"=>{"text"=>"test_search_string", "coltype"=>"risk"}, 
  #              "date"=>{"start_time"=>"1251877680000", "end_time"=>"1253864880000"}}}
  #f = LmiFilters.new(params)
  #f.filters => [{"text"=>"test_search_string", "coltype"=>"risk"}, 
  #              {"date[end_time]=1253864880000", "date[start_time]=1251877680000"}]
    params[:type] = filter_type()
    filter = LmiFilter.new(params, stored)
    session[:logdb] = log_db.new(filter)
    session[:lines] = session[:logdb].find_current(FILTERED_PAGE_SIZE, ZOOM_PAGE_SIZE)
  end
  
  def reset_logdb
    ftype = filter_type()
    filter = LmiFilter.blank()
    session[:logdb] = log_db.new(filter)
    session[:lines] = session[:logdb].find_current(FILTERED_PAGE_SIZE, ZOOM_PAGE_SIZE)
  end
end
