class SessionsController < ActionController::Base
  
  TIMEOUT = 120  
  def index
    @request_uri = params[:uri].blank? ? "" : "?uri=#{params[:uri]}"
    @max_timeout = TIMEOUT
    @last_user = Time.now
    @created = Time.now
    @active_username = 'Another user'
    @active_access_level = 'ReadOnly'
    @take_over = true
    @timeout = 0
        
    @asking_access_level = get_asking_privileges(request.env["REMOTE_USER"])
    
    user = User.find(:first)
    collect_active_user_information(user)    
    check_for_take_over_permission
         
    respond_to do |format|
      format.html {render :layout => "minimal"}
    end 
  end
  
  def take_over
    request_uri = params[:uri].blank? ? "/main/dashboard" : params[:uri]
    @max_timeout = TIMEOUT
    @last_user = Time.now
    @created = Time.now
    @active_username = 'Another user'
    @active_access_level = 'ReadOnly'
    @take_over = true
    @timeout = 0
    
    request.env["REMOTE_USER"] = "admin" if RAILS_ENV=="development"
    @asking_user = request.env["REMOTE_USER"]
    @asking_access_level = get_asking_privileges(@asking_user)
    
    user = User.find(:first)
    collect_active_user_information(user)    
    check_for_take_over_permission
    
    if @take_over && !user.nil?
      User.take_over_session(user.username)
      redirect_to :controller=> request_uri
    else
      redirect_to :controller=>'/sessions'
    end
  end
  
  def logout
    @logout = false

    user = User.find(:first)
    if session[:user]
      if session[:user].session_id == user.session_id
        @logout = true
        User.logout
      end    
    end
    
    # Do we take-over or disallow them from loging out
    if @logout
      respond_to do |format|
        format.html {render :layout => "minimal"}
      end     
    else
      redirect_to :controller=>'/sessions'
    end
  end

  def valid
    render :text => valid_session? 
  end

  private
  def valid_session?
    ! session[:user].blank?
  end
  
  def get_asking_privileges(user)
    user = "admin" if RAILS_ENV == "development"
    access_level = User.set_access_level(user);
    
    return access_level
  end
  
  def check_for_take_over_permission
    if (@asking_access_level == "ReadOnly" and @active_access_level == "Admin")
      stale_session_time = ((Time.now - @last_used)/60).round
      
      if stale_session_time < @max_timeout
        @take_over = false
        @timeout = @max_timeout - stale_session_time
      end
    end
  end
  
  
  def collect_active_user_information(user)
    unless user.nil?
      active_session = Session.find(:first)
      unless active_session.nil?
        @last_used = active_session.updated_at.localtime
        @created = active_session.created_at.localtime
      end
      
      @active_username = user.username      
      @active_access_level = user.access_level
    end 
  end
end
