class SettingsController < ApplicationController
  filter_parameter_logging :content0, :content1, :content2, :content3, :content4, :content5, :content6, :content7, :content8, :content9
  protect_from_forgery :only => [:update, :destroy]
  attr_reader :applet, :namespace, :policy, :tabloc, :readonly, :id, :url_base

  def index
    setup(params[:id])
  end
  
  def setup(id)
    set_policy_attributes(id)
    publicize_policies_on_server
  end

  def create
    if readonly?
      logger.warn "SettingsController.save_all: A readonly user is attempting to save policies"
      render :nothing => true, :status => 401
    else
      exitcode = Policy::Server.save_from_cpe_params(params)
      setup(params[:id])
      #render :text => "OK", :status => 200
       render :text => exitcode, :status => 200 
    end
  end
  
  def refresh_policy
    setup(params[:id])
    policy = CpeProperty.find_by_namespace(@namespace)
    if policy.nil?
      render :nothing => true, :status => 404
    else 
#      Policy::Server.retrieve_policy_from_crm(policy)   // LC - This seems to be redundance with the call to setup
      render :nothing => true, :status => 204
    end
  end
  
  # private
  def set_policy_attributes(id)
    @id = id
    @link = session[:currentnode] = Link.find(@id)
    @applet = AppletParams.new(@id, request.protocol, request.host, request.port_string)
    
    @namespace = @link.cpe_property.namespace
    @policy = @link.cpe_property.policy
    @tabloc = @link.cpe_property.tabloc
    @readonly = user_readonly?(@namespace)
    @url_base = @applet.url_base
  end
  
  def readonly?
    @readonly
  end
  
  def user_readonly?(ns)
    current_user = User.find_by_username(user)
    (current_user.nil? || current_user.access_level == "ReadOnly" || Appliance.managed_read_only?(ns))
  end
  
  def publicize_policies_on_server
    policy = @link.cpe_property
    Policy::Server.publicize_each_non_crm_policy
    if Policy::Server.retrieve_policy_from_crm?(policy)
      Policy::Server.publicize_policy(policy)
    end
  end
  
  def user
    request.env["REMOTE_USER"] = "admin" if dev?
    request.env["REMOTE_USER"]
  end
end
