class Setup::ServiceAgreementController < Setup::SetupController
  #layout "setup", :except=>:non_ibm_text
  layout :configure_layout, :except => :non_ibm_text
  
  def index
    session[:ignore_setup_warning] = nil
    set_language("en")
  end
  
  def select_language
    lang = get_captions(params[:id])
    lang["text"] = get_license_text(params[:id])

    respond_to do |format|
      format.json{ render :json =>  lang}
    end
  end
  
  def set_language(lang)
    @language_text = get_license_text(lang)
    @caption_hash = get_captions(lang)
  end

  def non_ibm_text
    @non_ibm_lic_text = get_non_ibm_text
  end

  def tou
    @tou =  get_ibm_tou
  end
  
  def accept_sla
    altnav = params[:altnav]
    
    unless altnav.blank?
      navigate(altnav)
      return
    end
    
    set_sla
    redirect_to :controller=>:license
  end  

  def decline_sla
    remove_sessions
    session[:ignore_setup_warning] = true
    unset_sla
    redirect_to :controller=>:welcome  
  end

  
  def navigate(altnav)
    redirect_to :controller => "/setup/#{altnav}"
  end

  private
  def set_sla
    session[:sla_set] = true
    %x[touch #{ROOTDIR}etc/lmi/sla/cli && touch #{ROOTDIR}etc/lmi/sla/lmi]  
  end
  
  def unset_sla
    %x[rm -f #{ROOTDIR}etc/lmi/sla/cli && rm -f #{ROOTDIR}etc/lmi/sla/lmi]  
  end
  
  
  def get_license_text(lang)
    return get_license(lang)
  end
  
  def get_license(lang)
    lang_file = "#{FOLDER_SLA}/la/LA_#{lang}"
    
    File.open(lang_file, "r") do |file|
      return Utility.format_file_text(file.read)
    end
  end
  
  
  def get_captions(lang)
    # localized caption files may be incomplete - merge over full english caption.
    caption_hash_en = get_captions_from_file("en")
    caption_hash_lang = get_captions_from_file(lang)
    caption_hash_en.merge(caption_hash_lang)
  end
  
  def get_captions_from_file(lang)
    caption_hash = {}
    lang_file = "#{FOLDER_SLA}/captions/captions_#{lang}"
    
    File.open(lang_file, "r") do |file|
      file.each_line do |line| 
        split_array = line.split("=")
        value = split_array[1].delete('"')
        caption_hash[split_array[0]] = value if value != ""
      end
    end
    return caption_hash
  end
  
  def get_non_ibm_text
    non_ibm_file = "#{FOLDER_SLA}/la/non_ibm_license"
    
    File.open(non_ibm_file, "r") do |file|
      return Utility.format_file_text(file.read)
    end
  end

  def get_ibm_tou
    non_ibm_file = "#{FOLDER_SLA}/tou.txt"
    
    File.open(non_ibm_file, "r") do |file|
      return Utility.format_file_text(file.read)
    end
  end

 def remove_sessions
    session[:welcome_set] = nil
    session[:sla_set] = nil
    session[:export_set] = nil
    session[:password_set] = nil
    session[:management_interfaces_set] = nil
    session[:security_interfaces_set] = nil
    session[:datetime_set] = nil
    session[:site_protector_set] = nil
    session[:updates_set]
  end

  def configure_layout
    request.request_uri =~ /setup/ ? "setup" : "application"
  end   
end
