class SnortProfilesController < ApplicationController
  layout :set_layout
  
  def index
    @snort_enabled = Appliance.snort_enabled?
    @snort_profiling_enabled = Appliance.snort_profiling_enabled?
    @snort_running = Appliance.snort_running?
    @snort_health = Appliance.snort_health
    begin
      @profiles = SnortProfileOutput.all
    rescue ApplianceExceptions::LogreadException
      @error = true
      flash[:notice] = "There are no SNORT rule profiles to display"
      @profiles = []
    end
  end
    
  def show
    name = params[:path_info].to_s  #if decide to use for browser display, need to sanitize to prevent XSS
    params[:file] = File.basename(name)
    file = params[:file]
    if file = SnortProfileOutput.fullpath(name)
      send_file file, :stream=>false
    else
      session[:error] = true
      flash[:notice] = "Unable to locate SNORT rule profile for download: #{file}"
      redirect_to :action => "index"
    end
  end
  
  def destroy
    name = params[:path_info].to_s  #if decide to use for browser display, need to sanitize to prevent XSS
    params[:file] = File.basename(name)
    file = params[:file]
    if filepath = SnortProfileOutput.fullpath(name)
      # delete the rule profile log
      result = `#{ROOTDIR}usr/bin/issasApache -a cta -pns http://www.iss.net/cml/NetworkDefender/ctSnortActionCommand -pv 1.0 -sv 1.0.0 -atn Action -atv del_file -atn2 Param -atv2 #{file}`
      if result.strip == "OK"
        flash[:notice] = "Deleted SNORT rule profile: #{file}"
      else
        session[:error] = true
        flash[:notice] = "Encountered an error while deleting SNORT rule profile: #{file}"
      end
    else
      session[:error] = true
      flash[:notice] = "Unable to locate SNORT rule profile to delete: #{file}"
    end
    redirect_to :action => "index"
  end
  
  def delete_all
    # delete all rule profile logs
    result = `#{ROOTDIR}usr/bin/issasApache -a cta -pns http://www.iss.net/cml/NetworkDefender/ctSnortActionCommand -pv 1.0 -sv 1.0.0 -atn Action -atv del_file -atn2 Param -atv2 "*"`
    if result.strip == "OK"
      flash[:notice] = "Deleted all SNORT rule profiles"
    else
      session[:error] = true
      flash[:notice] = "Encountered an error while deleting all SNORT rule profiles"
    end
    redirect_to :action => "index"
  end
  
  def refresh
    recent_before = most_recent_profile_name
    # bounce Snort to force new rule profile to be generated
    result = `#{ROOTDIR}usr/bin/issasApache -a cta -pns http://www.iss.net/cml/NetworkDefender/ctSnortActionCommand -pv 1.0 -sv 1.0.0 -atn Action -atv refresh_profile`
    if result.strip == "OK"
      #TODO do this polling with jquery instead of in controller
      # wait for Snort to generate new profile log (timeout = 5 seconds)
      recent_after = most_recent_profile_name
      duration = 0.0
      while recent_after == recent_before do
        sleep(0.5)
        duration += 0.5
        recent_after = most_recent_profile_name
        break if duration >= 5.0
      end
   else
     session[:error] = true
     flash[:notice] = "Encountered an error while retrieving the most recent SNORT rule profile."
   end

    redirect_to :action => "index"    
  end
  
  def view
    file = SnortProfileOutput.fullpath(params[:path_info])
    profile_file = SnortProfileOutput.new(file)
    
    session[:file] = profile_file.filename
    session[:title] = ""
    session[:header] = [] 
    session[:rows] = []
    session[:lines] = []
    
    refresh_output(profile_file)

    render :layout => 'minimal'
  end  
    
  def set_layout
    ajax? ? false : "application"
  end
  
  private
  def refresh_output(profile_file)
    output = profile_file.get_output()
    if (output.length > 3)
      session[:title] = output[0]
      session[:header] = output[2]
      session[:rows] = output[4..-1]
    end
    session[:lines] = output
  end
  
  def most_recent_profile_name
    begin
      profile = SnortProfileOutput.all.first
      (profile == nil) ? "" : profile.filename
    rescue ApplianceExceptions::LogreadException
      ""
    end
  end   
  
end