class UpdatesController < ApplicationController
  before_filter :update_interface
  protect_from_forgery :only=>[:upload_update, :upload_license]
  def index
    #cookies[:_lmi_session] = {:secure=>true}
    load_software_info()
    @security_module = StatusEntry.find(params[:id].nil? ? "1" : params[:id])
    if @security_module.licensed == 2
      flash[:notice] = Message.new(:first_time_load, :error).text 
      session[:error] = true
    end

    unless session[:messages].nil?
      @messages = session[:messages]
      session[:messages] = nil
    end

    respond_to do |format|
      format.html # index.html.erb
      format.xml
      format.json {render :json => @all}
      format.rss {render :layout => false}
    end
  end
  

  def show
    @security_module = StatusEntry.find(params[:id])
    respond_to do |format|
      format.xml
      format.json {render :json => @security_module}
    end
  end


  #Non restful support methods  
  def install_firmware
    Lum.update_firmware
    Policy::SensorInfo.clear_index
    User.take_over_session("firmware_install")
    reset_session
    render :layout => 'minimal'
  end
      
  def install_update
    @security_module = StatusEntry.find_by_name("Intrusion Prevention")
    session[:messages] = Lum.update
    Policy::SensorInfo.clear_index
    render :nothing => true
  end
  
  def rollback_update
    @security_module = StatusEntry.find_by_name("Intrusion Prevention")
    session[:messages] = Lum.rollback
    render :nothing => true
  end
  
  def is_db_update_in_progress
    render :text => Lum.db_update_in_progress?
  end
  
  def view_update_history
    @updates = UpdateHistory.paginate :page => params[:page], :per_page => 17, :order=>"date desc"
    render :layout => 'minimal'
  end
  
  def view_update_log
    fname = params[:id]
    test_arr = fname.split("/")
    clean_str = ""
    if test_arr && test_arr.kind_of?(Array)
      clean_str = test_arr[-1]
    end 
    path = "#{UPDLOGSDIR}#{clean_str}"
        
    @log_file = "<div id='log_file_container'>"
    
    begin
     raise ApplianceExceptions::FileNotFound unless File.exists?(path)
      File.open(path, "r") do |file|
        @log_file << format_file_text(file.read)
      end
    rescue ApplianceExceptions::FileNotFound
      @log_file << "Could not locate the log file #{CGI.escapeHTML(path)} on the system."
    end
      @log_file << "</div>"
    render :layout => 'minimal'    
  end
  
  def format_file_text(file)
    CGI.escapeHTML(file).gsub("\n", "<br />")
  end
  
  def onetrust_help
    render :layout => 'minimal'
  end
  
  def legacy_help
    render :layout => 'minimal'
  end
  
  def eval_help
    render :layout => 'minimal'
  end
  
  
  def upload_update
    session[:messages] = {}
    id = params["update"]["module_id"]
    @all = StatusEntry.all 
    @security_module = StatusEntry.find(id)    
 
    begin
      UpdateFile.save(params)
      session[:messages] = Lum.find_local_updates
    rescue ApplianceExceptions::FileBlank
      logger.error "Rescued ApplianceExceptions::Blank exception"
      session[:messages][:status_failure] = {:blank_file => "You must select a valid security update file to upload"}
    rescue ApplianceExceptions::FileTooLarge
      logger.error "Rescued ApplianceExceptions::FileTooLarge exception"
      session[:messages][:status_failure] = {:too_large => Message.new(:file_too_large, :error).text}
    rescue ApplianceExceptions::FileNotFound
      logger.error "Rescued ApplianceExceptions::FileNotFound exception"
      session[:messages][:status_failure] = {:not_found => Message.new(:file_not_found, :error).text}
      session[:messages] = Message.new(:file_not_found, :error).text
    end

    redirect_to :action => :index
  end
  
    
  def upload_license
    session[:messages] = {}
    id = params["license"]["module_id"]
    @all = StatusEntry.all 
    @security_module = StatusEntry.find(id)    
 
    begin
      LicenseFile.save(params)
      session[:messages] = LicenseFile.install(params)
    rescue ApplianceExceptions::FileBlank
      logger.error "Rescued ApplianceExceptions::Blank exception"
      session[:messages][:status_failure] = {:blank_file => "You must select a valid license file to upload"}
    rescue ApplianceExceptions::FileTooLarge
      logger.error "Rescued ApplianceExceptions::FileTooLarge exception"
      session[:messages][:status_failure] = {:too_large => Message.new(:file_too_large, :error).text}
    rescue ApplianceExceptions::FileNotFound
      logger.error "Rescued ApplianceExceptions::FileNotFound exception"
      session[:messages][:status_failure] = {:file_not_found => Message.new(:file_not_found, :error).text}
    end

    redirect_to :action => :index
  end
  
  def find_updates
    session[:messages] = Lum.find_updates
    render :nothing => true
  end

  private 
  def get_current_module_id(val)
    val.nil? ? "1"  : val
  end
  
  def update_interface
    Lum.load_data
  end
end

