class Event
  attr_accessor :vlan_id, :block_duration, :block_ip
  DBT_BLOCK_NAMESPACE = "http://www.iss.net/cml/NetProtectModule/ctDBTAddDeleteRule"

  def initialize(srcip, vlanid, block_duration=nil)
    @block_ip = srcip
    @vlan_id = vlanid
    @block_duration = duration_in_seconds(block_duration)
    @schema_version = Policy::SensorInfo.schema_version_by_namespace(DBT_BLOCK_NAMESPACE)
    @policy_version = Policy::SensorInfo.policy_version_by_namespace(DBT_BLOCK_NAMESPACE)
  end

  def block
    cmd = "-a ctas -pns #{DBT_BLOCK_NAMESPACE} -pv #{@policy_version} -sv #{@schema_version} -nvt AddDeleteRule -nvs "
    cmd += "'"
    cmd += "Operation=ADD,SrcIP=#{@block_ip},Duration=#{@block_duration},FullDuplex=true"
    cmd += (@vlan_id.nil? or @vlan_id.to_i < 1 or @vlan_id.to_i > 4096) ? "" : ",VLAN=#{@vlan_id}"
    cmd += "'"
    raise ApplianceExceptions::SystemExecuteException unless Issasapache.execute(cmd) == 0
  end
  
  private
  def duration_in_seconds(block_duration)
    case block_duration
      when "hour" : return 60 * 60
      when "day"  : return 24 * 60 * 60
      when "week" : return 7 * 24 * 60 * 60
      when "month" : return 30 * 24 * 60 * 60
    end
  end
end
