class SiteProtector < ActiveRecord::Base
  attr_accessor :password_confirmation
  #General validation  
  validates_presence_of :group, :name, :address, :port, :if => :requires_validator?
  validates_confirmation_of :password, :if => :requires_validator?

  #Address validation
  validates_net_address :address, :if => :requires_validator?
  validates_numericality_of :port, :integer_only => true, :greater_than => 0, :less_than => 65536, :if => :requires_validator?

  #Connection interval validation
  validates_presence_of :connection_interval, :if => :requires_validator?
  validates_numericality_of :connection_interval, :integer_only => true, :greater_than => 299, :if => :requires_validator?

  #Proxy validation
  validates_presence_of :proxy_address, :proxy_port, :if => :requires_proxy_validator?
  validates_net_address :proxy_address, :if => :requires_proxy_validator?
  validates_numericality_of :proxy_port, :if => :requires_proxy_validator?

  def before_save
    if !register_with_site_protector?
      self.group = nil
      self.name = nil
      self.username = nil
      self.password = nil
      self.address = nil
      self.port = nil
      self.proxy_port = nil
      self.proxy_address = nil
      self.trust_level = nil
      self.crypto_level = nil
      self.proxy_username = nil
      self.proxy_password = nil
    end
  end

  def requires_validator?
    register_with_site_protector?
  end

  def requires_ipv6_validator?
    requires_validator? and ipv6_address?
  end

  def requires_ipv4_validator?
    requires_validator? and !ipv6_address?
  end

  #proxy validation test
  def requires_proxy_validator?
    requires_validator? and use_proxy?  
  end

  def requires_proxy_ipv6_validator?
    requires_proxy_validator? and ipv6_proxy_address?
  end

  def requires_proxy_ipv4_validator?
   requires_proxy_validator? and !ipv6_proxy?
  end

  def use_proxy?
    self.use_proxy
  end

  def register_with_site_protector?
    self.register_with_site_protector
  end

  def proxy_auth?
    self.proxy_auth_required
  end

  def ipv6_address?
    self.ipv6_address
  end

  def ipv6_proxy?
    self.ipv6_proxy_address
  end

  def proxy_auth_required?
    self.proxy_auth_required
  end

  def proxy_authentication?
    use_proxy? and proxy_auth?
  end

  def self.configure
    sp = find(:first)
    args = {}
    args["pSchemaVersion"] = "5.0.1"
    args["pRegister"] = sp.register_with_site_protector
    args["pUseLocalSettings"] = sp.local_override
    args["pGroupName"] = sp.group
    args["pHeartbeatInterval"] = sp.connection_interval
    args["pCryptoLevel"] = sp.crypto_level
    args["pSpaLogLevel"] = "normal"
    args["pAgentManagers"] = agent_manager_string(sp)
    Setup::configure_site_protector(args)
  end

  def self.register?
    begin
      sp = find(:first)
      return sp.register_with_site_protector
    rescue
      return false
    end
  end

  def self.agent_manager_string(sp)
    str = ""
    if sp.proxy_port.blank?
      sp.proxy_port = "3128"
    end
    
    encrypted_password = `#{ROOTDIR}usr/bin/sudo /usr/bin/provgSetupCmd sppass --encrypt '#{sp.password}' 2>&1`
    raise_error(encrypted_password) unless $?.exitstatus == 0

    str << "#{sp.trust_level}\##{sp.name}\##{sp.address}\##{sp.port}\#"
    str << "#{sp.username}\##{encrypted_password.strip}\##{sp.use_proxy}"
    str << "\##{sp.proxy_address}\##{sp.proxy_port}"
    str
  end

  TRUST_LEVELS = [['First Time', 'first-time-trust'],
        ['Explicit', 'explicit-trust'],['Trust All', 'none']].freeze
  CRYPTO_LEVELS = [['Compatible Cryptography', 'compatible'],
                   ['Strict Cryptography', 'strict']].freeze
end
