class User < ActiveRecord::Base
  require 'syslog'
  require "rexml/document"
  include REXML

  def after_initialize
    self.access_level = User.set_access_level(self.username)
  end

  def self.set_access_level(username)
    access_level = ""
    policy = nil
    begin
      policy = Document.new File.new("#{FOLDER_SYSTEM_POLICY}/access/npaccess5_0.xml") 
    rescue
      User.log "#{Time.now} user.access_level -- Error opening the policy #{FOLDER_SYSTEM_POLICY}/users/user.xml"
    end

    begin
      access_level = policy.elements.to_a("//RemoteAuthTab/RemoteUsers/User[@UserName='#{username}']")[0].attributes["Category"]
    rescue
      User.log "#{Time.now} user not found in remote user list.  Providing LMI readonly access"
      access_level = "ReadOnly"  
    end
    access_level
  end
  
  def self.create_new_session(username, session_id)
    user = User.new({:session_id => session_id, :username => username})
    user.save!
    log "#{Time.now} user '#{username}' logged into the LMI with '#{user.access_level}' access."
    user
  end
  
  def self.take_over_session(username)
    Session.delete_all
    User.find(:all).each do |u| 
      log "#{Time.now} user '#{username}' took over the LMI session from user '#{u.username}' ."
      u.delete
    end
  end
  
  def self.logout
    Session.delete_all
    User.find(:all).each do |u| 
      log "#{Time.now} user '#{u.username}' logged out of the LMI"
      u.delete
    end
  end
  
  def self.log(msg)
    s = Syslog.open('LMI::Auth', Syslog::LOG_PID | Syslog::LOG_NDELAY, Syslog::LOG_AUTH)
    s.log(Syslog::LOG_INFO, msg)
    s.close
  end
end
