module LmiValidators
  class IPv6Validator
    @matchers = {
      :preferred => [/^(?:[a-f0-9]{1,4}:){7}[a-f0-9]{1,4}$/i],
      :compressed => [/^[a-f0-9]{0,4}::$/i,
        /^:(?::[a-f0-9]{1,4}){1,6}$/i,
        /^(?:[a-f0-9]{1,4}:){1,6}:$/i,
        /^(?:[a-f0-9]{1,4}:)(?::[a-f0-9]{1,4}){1,6}$/i,
        /^(?:[a-f0-9]{1,4}:){2}(?::[a-f0-9]{1,4}){1,5}$/i,
        /^(?:[a-f0-9]{1,4}:){3}(?::[a-f0-9]{1,4}){1,4}$/i,
        /^(?:[a-f0-9]{1,4}:){4}(?::[a-f0-9]{1,4}){1,3}$/i,
        /^(?:[a-f0-9]{1,4}:){5}(?::[a-f0-9]{1,4}){1,2}$/i,
        /^(?:[a-f0-9]{1,4}:){6}(?::[a-f0-9]{1,4})$/i],
      :ipv6_parse_ipv4_compressed => [/^::(?:ffff:)?(?:\d{1,3}\.){3}\d{1,3}$/i],
      :ipv6_parse_ipv4 => [/^(?:0:){5}ffff:(?:\d{1,3}\.){3}\d{1,3}$/i,
	      /^(?:0:){6}(?:\d{1,3}\.){3}\d{1,3}$/]}

    def self.validate(arg)
      match = false
      @matchers.map do |k, v|
        v.each{|matcher| match = true if arg =~ matcher}
      end
      match 
    end
  end

  class IPv4Validator
    @matcher = /\A(?:25[0-5]|(?:2[0-4]|1\d|[1-9])?\d)(?:\.(?:25[0-5]|(?:2[0-4]|1\d|[1-9])?\d)){3}\z/ 
   
    def self.validate(arg)
      arg =~ @matcher ? true : false
    end
  end

  class ShortHostNameValidator  
    ########################################################################################################### 
    # Valid hostname expression.  Keep this for future use as our appliances currently do not follow          #
    # the standard for valid hostnames but may in the future.                                                 # 
    # @matcher = /^[a-z0-9]+([a-z0-9]\.|[a-z0-9][-a-z0-9_]{0,61}[-a-z0-9_]\.)*([-a-z0-9_]{0,61}[a-z0-9])+$/i  #
    ########################################################################################################### 
    @matcher = /^[a-z0-9]([-a-z0-9_]{0,49})$/i
    def self.validate(arg)
      arg =~ @matcher ? true : false
    end
  end
  
  class HostNameValidator  
    ########################################################################################################### 
    # Valid hostname expression.  Keep this for future use as our appliances currently do not follow          #
    # the standard for valid hostnames but may in the future.                                                 # 
    # @matcher = /^[a-z0-9]+([a-z0-9]\.|[a-z0-9][-a-z0-9_]{0,61}[-a-z0-9_]\.)*([-a-z0-9_]{0,61}[a-z0-9])+$/i  #
    ########################################################################################################### 
    @matcher = /(?=^.{1,63}$)(^(?:(?!\d+\.)[a-zA-Z0-9_\-]{1,63}\.?)+(?:[a-zA-Z]{2,})$)/i
    def self.validate(arg)
      arg =~ @matcher ? true : false
    end
  end
  
  class NetAddressValidator
    def self.validate(arg)
      return true if ShortHostNameValidator.validate(arg)
      return true if HostNameValidator.validate(arg)
      return true if IPv4Validator.validate(arg)
      return true if IPv6Validator.validate(arg)
      return false
    end
  end
end
