class DbLogCache < LogCache
  require "logger"
  
  attr_reader :db_cache, :filter, :cleaned, :reset
  alias :super_page_end :page_end
  alias :super_page_begin :page_begin
  
  def initialize(file_preffix,filter,page_size=50,live_view=0)
    @filter = filter    
    @file_preffix = file_preffix
    @cleaned=false
    @reset=false
    @live_view = live_view
    
    @db_cache = Array.new    
    size = initialize_cache
    super(size,page_size)
  end

  def page_current
    describe_page
    find
  end

  def page_older
    super
    describe_page
    find
  end

  def page_newer
    super
    describe_page
    find
  end

  def page_begin
    super
    describe_page
    find
  end
  
  def page_end
    super
    describe_page
    find
  end
  
  def find
    # look for modified databases
    clean_cache

    start_index, end_index = get_index_range
    index = 0
    pgsize = end_index - start_index
    logIt("start_index (#{start_index}) and end_index (#{end_index}) || pgsize: #{pgsize}", 0, 'find','DbLogCache')
    lines = Array.new
    
    @db_cache.each do |db|
      break if lines.length == @page_size or end_index <= index
      next if db.size == 0
    
      total_index = db.size + index
      if total_index < start_index 
        index = total_index
        next
      end
    
      if lines.length == 0
        offset = db.size - (total_index - start_index)
        lines = db.find(offset,pgsize)
      else
        lines.concat db.find(0, pgsize - lines.length)
      end   

      index = total_index
    end

    return lines.reverse
  end
  
  def start_index_on_page
   get_index_range[0]
  end

  def end_index_on_page
   get_index_range[1]
  end
  
  private
    
  ###################
  # grab_files 
  ###################
  def grab_files
    filelist = Array.new
    log = @file_preffix

    i = 1
    while FileTest.exists?(log) do
      filelist.push(log)
      suffix = log_suffix(i)
      log = "#{@file_preffix}.#{suffix}"
      i += 1
    end

    filelist
  end

  ###################
  # log_suffix 
  ###################
  def log_suffix(i)
    if i < 10
      suffix = "00#{i}"
    elsif i < 100
      suffix = "0#{i}"
    else
      suffix = i
    end
    
    suffix
  end

  #####################
  # initialize_cache
  #####################
  def initialize_cache
    total_lines = 0
    filelist = grab_files
    if (@live_view != 0)
      topfile =  filelist.sort_by {|f| File.mtime(f).to_i}.reverse[0]
      filelist = [topfile]
    end
    filelist.sort_by {|f| File.mtime(f).to_i}.each do |file|
      begin
        @db_cache.push AlertLogModel.new(file, @filter)  
      rescue => ex
        RAILS_DEFAULT_LOGGER.error "Problems calling AlertLogModel on #{file}  Exception: #{ex.class.to_s} : #{ex.message.to_s}"
        next      
      end
      total_lines += @db_cache[-1].size
    end

    total_lines
  end
  
  def get_index_range
    start_index = @size - (@page_number*@page_size)
    end_index = start_index + @page_size
    start_index = 0 if start_index < 0
    return start_index,end_index
  end

  def clean_cache
    @cleaned = false
    @reset = false

    cache_size = @db_cache.length
    return if cache_size = 0
    i=0
    while i < 1
      db = @db_cache[i]
      if 1 == @db_cache.length and db.modified?
	    logIt("Reached end of cached db files, all files have changed under us",1,'clean_cache','DbLogCache',false)
        logIt("Recreating the entire cache",1,'clean_cache','DbLogCache',false)
        reset_db_cache
        @reset = true        
        break
      elsif db.modified?
	    logIt("Round Robin DB #{db.database_path} has changed, removing from cache.",1,'clean_cache','DbLogCache',false)
        @cleaned = true
        remove_db(db,i)
        next
      end      
      i += 1
    end
  end


  def remove_db(db,index)
    @size -= db.size
    @db_cache.slice!(index)
   
    if @page_number > max_page_number
      super_page_end()
    end        
  end
  
  def reset_db_cache
    @db_cache = Array.new    
    @size = initialize_cache
    super_page_begin()
  end 

  def describe_page
    msg = "Currently on page #{@page_number} of #{max_page_number}"
    logIt(msg, 1, 'Describe Page', 'DbLogCache',false)
  end 
end
