module HostInfo
  require 'timeout'
  require 'socket'
  require 'resolv'
  
  def HostInfo.find_name_by_address(address)
    host_name = address 
    begin
      timeout(5) do
        if IPv4Validator.validate(host_name)
          host_name = Resolv.getname(address)
          RAILS_DEFAULT_LOGGER.info "[#{Time.now}] IPV4 HostInfo.find_name_by_address:  Address='#{address}' Hostname='#{host_name}'"  
        elsif IPv6Validator.validate(host_name)
          Socket.do_not_reverse_lookup=false
          address_info = Socket.getaddrinfo(address,nil)
          host_name = address_info[0][2]
          RAILS_DEFAULT_LOGGER.info "[#{Time.now}] IPV6 HostInfo.find_name_by_address:  Address='#{address}' Hostname='#{host_name}'"
        else
          RAILS_DEFAULT_LOGGER.info "[#{Time.now}] UnknownValue HostInfo.find_name_by_address:  Address='#{address}'"  
        end
      end
    rescue Timeout::Error
      RAILS_DEFAULT_LOGGER.info "[#{Time.now}] HostInfo.find_name_by_address: Timed Out Address='#{address}'" 
    rescue Resolv::ResolvError
      RAILS_DEFAULT_LOGGER.info "[#{Time.now}] IPV4 HostInfo.find_name_by_address: Resolv Failed Address='#{address}'" 
     rescue Exception => e
       RAILS_DEFAULT_LOGGER.info "[#{Time.now}] HostInfo.find_name_by_address: Exception caught: #{e}(#{e.class})"   
    end

    host_name
  end

  def HostInfo.find_address_by_name(host_name)
    addresses = Array.new 
    begin
      timeout(5) do
        if HostNameValidator.validate(host_name)
          RAILS_DEFAULT_LOGGER.info "[#{Time.now}] HostInfo.find_address_by_name: Hostname='#{host_name}'"
          address_info = Socket.getaddrinfo(host_name, 0, Socket::AF_UNSPEC, Socket::SOCK_STREAM, nil, Socket::AI_CANONNAME)
          address_info.each do |a|
            addresses.push a[3]
          end
        else
          RAILS_DEFAULT_LOGGER.info "[#{Time.now}] UnknownValue HostInfo.find_address_by_name:  Address='#{host_name}'"  
        end
      end
    rescue Timeout::Error
      RAILS_DEFAULT_LOGGER.info "[#{Time.now}] HostInfo.find_address_by_name: Timed Out Hostname='#{host_name}'" 
    end

    addresses
  end

  
end
