class LogCache
  require 'logger'
  attr_reader :page_size
  attr_accessor :page_number, :size
  
  def initialize(size, page_size=50)
    @size = size
    @page_size = page_size
    @page_number = 1
    @debug = 0
  end
  
  def at_begin?
    @page_number == 1
  end
  
  def at_end?
    @page_number == max_page_number
  end

  def page_older
    if @page_number.to_i < max_page_number
      @page_number += 1
    elsif @page_number.to_i > max_page_number
      @page_number = max_page_number
    end
    @page_number
  end

  def page_newer
    if @page_number.to_i > 1
      @page_number -= 1
    end
    @page_number
  end

  def page_begin
    @page_number = 1
    @page_number
  end
  
  def page_end
    @page_number = max_page_number
    @page_number
  end

  def page_max_index(page_number=@page_number)
    @page_size*page_number
  end
  
  def max_page_number
    (@size/@page_size.to_f).ceil
  end

  def logIt(msg, overrideDebug=0, func='', filename='', hi_lite=true)
    if (!msg.nil? and ((!@debug.zero?) or (!overrideDebug.zero?)))
      wrap_head = ''
      wrap_tail = ''
      output = ''
      if (!filename.empty?)
        output += "[#{filename}] "
      end
      if(!func.empty?)
        output += "<#{func}> "
      end
      output << msg 
      if hi_lite
        wrap_head = "\e[1;34m"
        wrap_tail = "\e[0m"
      end
      output = wrap_head << ' ' << output << ' ' << wrap_tail
      RAILS_DEFAULT_LOGGER.info(output)
    end
  end
end
