module LogFile

  def LogFile.find(cache)
  
    cache.clean_cache

    total_lines, page_num, page_size = get_cache_values(cache)    
    start_index, end_index = get_index_range(total_lines, page_num, page_size)

    #puts "PAGE_NUM: #{page_num}, PAGE_SIZE: #{page_size}, TL: #{total_lines}"
    #puts "START_INDEX: #{start_index}, END_INDEX: #{end_index}"
    index = 0

    lines = Array.new
    
    cache.file_cache.sort_by {|v| sort_files(v[0])}.reverse_each do |file,data|
      lc = data[:size]
      break if lines.length == page_size or end_index == index
      next if lc == 0
    
      total_index = lc + index
      if total_index < start_index 
        index = total_index
        next
      end

      results = cache.get_filter_results(file)
      return [] if results.blank?
      
      page_index = 0
      file_length = results.length
    
      if lines.length == 0
        page_index = file_length -(total_index - start_index) 
        index +=page_index
      end

      while page_index < file_length 
        break if lines.length == page_size or end_index == index
        lines.push(results[page_index]) 
        index += 1
        page_index +=1
      end
      index = total_index if end_index != index
    end
  
    return lines.reverse
  end
  
  def LogFile.find_by_index(filtered_cache, unfiltered_cache, index)
    #puts "FIL Size: #{filtered_cache.size}"
    #puts "UNFIL Size: #{unfiltered_cache.size}"
    filtered_cache.clean_cache
    unfiltered_cache.clean_cache

    results = Array.new
    logfile, relative_index = determine_log_name(filtered_cache, index)
    #puts "LOGFILE: #{logfile}"
                                      
    abs_index = get_unfiltered_index(unfiltered_cache,filtered_cache.filter,logfile,relative_index)
    #puts "ABS_INDEX: #{abs_index}"
    unfiltered_cache.base_zoom_index = abs_index
    
    reverse_index = unfiltered_cache.size - abs_index 
    unfiltered_cache.base_zoom_index = reverse_index
    page_number = (reverse_index/unfiltered_cache.page_size.to_f).ceil
    page_number = 1 if page_number == 0
    #puts "Our Zoom Starts on Page: #{page_number}"
    unfiltered_cache.page_number = page_number
   
    #puts "Max Page Number: #{unfiltered_cache.max_page_number}"
    #puts "New Page Number: #{unfiltered_cache.page_number}"
    find(unfiltered_cache)
  end

  def LogFile.sort_files(name)
    name.split(/\./)[1].to_i    
  end
  
  private

  def LogFile.get_cache_values(cache)    
    return cache.size, cache.page_number, cache.page_size
  end
  
  def LogFile.get_index_range(total_lines, page_num, page_size)
    start_index = total_lines - (page_num*page_size)
    end_index = start_index + page_size
    start_index = 0 if start_index < 0
    
    return start_index,end_index
  end

  def LogFile.determine_page(index,page_size)
    (index/page_size.to_f).ceil
  end
  
  def LogFile.determine_previous_page(index,page_size)
    total_pages = determine_page(index,page_size)
    total_pages -= 1 if total_pages > 1
    total_pages
  end
  
  def LogFile.determine_log_name(cache, relative_index)
    target_file = ''

    total_lines, page_num, page_size = get_cache_values(cache)    
    start_index, end_index = get_index_range(total_lines, page_num, page_size)

    absolute_index = start_index + relative_index
    relative_index = absolute_index
    index = 0
    #puts "AB: #{absolute_index}"
    cache.file_cache.sort_by {|v| sort_files(v[0])}.reverse_each do |file,data|
      lc = data[:size]
      next if lc == 0
      #puts "FILE: #{file}, LC: #{lc}, Index: #{index}, RI: #{relative_index}"
      total_index = lc + index
      if total_index < absolute_index 
        index = total_index
        relative_index -= lc
        next
      end
      
      target_file = file  
      break      
    end    
        
    #puts "File: #{target_file} RI: #{relative_index}"
    
    return target_file, relative_index
  end

  def LogFile.find_index(cache,filter,file,index,relative_index)
    readlines = cache.retrieve_file_data(file)
    matches = 0
    
    #puts "INDEX START: #{index}"
    readlines.each do |line|
      index += 1
      
      next if filter.do_filter([line]).empty?
      
      matches += 1
      #puts "MATCHED #{matches}: #{index} #{line}"
      break if matches == relative_index
            
    end
    
    index
  end

  def LogFile.get_unfiltered_index(cache,filter,target_file,relative_index)
    index = 0 
    unfiltered_index = 0
    total_lines, page_num, page_size = get_cache_values(cache)
    
    cache.file_cache.sort_by {|v| sort_files(v[0])}.reverse_each do |file,data|
      lc = data[:size]
      total_index = lc + index
      if file != target_file
        index = total_index
        next
      end
      
      #puts "TI: #{total_index}, I: #{index}, RI: #{relative_index}"
 
      unfiltered_index = find_index(cache,filter,file, index, relative_index) 
      break
    end
    
    unfiltered_index
  end

end
