class NetworkState
  RRD_NAME = "drv"
  RRD_EXT = ".rrd"

  def self.appliance_state(strings)
    return {} if strings.blank?
    ret = {}
    prev_port = ""
    n = SqliteSource.new("network_info").data
    n.each do |net|
      iface = Adapter.find_by_port(net.port)
      return ret if iface.nil?
      
      if ret[iface.segment.port].nil?
        ret[iface.segment.port] = {iface.port => {
            :alpha_numeric_port => iface.alpha_numeric_port,
            :state => iface_state(net.connected),
            :duplex => strings[net.duplex], 
            :speed => speed_msg(net.speed), 
            :mode => strings[net.mode],
            :href=> href(strings[net.mode], iface)}}
         prev_port = iface.port
      else
        tmp1 = {iface.port => {
            :alpha_numeric_port => iface.alpha_numeric_port,
            :state => iface_state(net.connected),
            :duplex => strings[net.duplex], 
            :speed => speed_msg(net.speed), 
            :mode => strings[net.mode],
            :href=> href(strings[net.mode], iface)}}
            
        tmp2 = ret[iface.segment.port]
        ret[iface.segment.port] = {:state => segment_state(tmp1[iface.port], tmp2[prev_port]),
                                   :mode => tmp1[iface.port][:mode]}.merge(tmp1).merge(tmp2)
      end
    end
    ret
  end

  def self.get_first_segment(state)
    #state.keys.sort.shift.to_s
    # state.keys represent hash keys for each segment
    state.keys.sort.each do |port|
      return port if state[port][:mode] =~ /inline/ || state[port][:mode] =~ /simulated/
    end
  end

  def self.get_first_interface(state)
    state.keys.sort.each do |port|
      if state[port][:mode] =~ /monitor/
        iface_keys = state[port].keys
        iface_keys.delete(:mode)
        iface_keys.delete(:state)

        return iface_keys.sort.first
        #iface_keys.sort.each do |ikey|
        #  return ikey if state[port][ikey][:mode] =~ /monitor/
        #end
      end
    end
  end


  def self.segments
    Segment.all
  end

  def self.config_counts(state)
    counts = {:segment => 0, :interface => 0}
    return counts if state.blank?
    
    keys =  state.keys
    keys.each_with_index{|k, i| keys[i] = k.to_i}
    keys.sort

    keys.each do |k|
      ifaces = state[k.to_s]
      iface_keys = ifaces.keys
      iface_keys.delete(:mode)
      iface_keys.delete(:state)
      iface_keys.sort

      iface_keys.each do |ikey|
        iface = ifaces[ikey]
        if iface[:mode] =~ /monitor/
          counts[:interface] += 2
          break
        elsif iface[:mode] =~ /inline/ || iface[:mode] =~ /simulated/
          counts[:segment] += 1
          break
        end
      end      
    end
    return counts
  end  

  def self.network_available?
    arg = status_counts
    adapter_count = SqliteSource.new("network_info").data.size
    (adapter_count > 0) && (arg["up"] != 0 or arg["down"] != 0 or arg["disabled"] != 0)
  end

  def self.status_counts
    network = SqliteSource.new("network_info").data
    counts = {'up'=>0, 'down'=>0, 'disabled'=>0}
    return counts if network.blank?

    network.each do |interface|
      if interface.connected == "1"
        counts["up"] += 1
      else
        counts["down"] += 1
      end      
    end
    counts
  end

  def self.iface_state(code)
    code == "1" ? "up" : "down"
  end

  def self.segment_state(iface1, iface2)
    return "down" if iface1[:state]=="down" or iface2[:state] == "down"
    return "up" if iface1[:state] == "up" and  iface2[:state] == "up"
    return "disabled"
  end

  def self.msg(key)
    begin
    SystemMessage.find_by_key(key).val
    rescue
      return "Unknown"
    end
  end

  def self.href(mode, iface)
    seg = "/statistics/segments/bandwidth/#{iface.segment.port}"
    iface = "/statistics/interface/bandwidth/#{iface.port}"
    mode =~ /monitor/ ? iface : seg
  end

  def self.speed_msg(key)
    key == "-1" ? "0" : "#{key} Mb/s"
  end

  def self.get_render_method(state)
    config_counts(state)[:segment] == 0 ? "interface" : "segment"
  end


  def self.set_nav
    links = Link.find(:all, :conditions => ["controller_name like ? \
      or controller_name like ?", "%packets", "%bandwidth"])
    c = config_counts

    links.each do |l|
      str = l.link_title.gsub(/\sBandwidth/, "").gsub(/\sPackets/,"").downcase!
      if c[str.to_sym] < 1 and l.enabled
       l.enabled = false
        l.save!
      elsif c[str.to_sym] > 0 and !l.enabled
        l.enabled = true
        l.save!
      end
    end
  end

  def self.get_resolution_and_timespan(history)
    case history
    when "hour"
      return 60, "1h"
    when "day"
      return 300, "1d"
    when "week"
      return 900, "7d"
    when "month"
      return 3600, "30d"
    else
      #default value
      return 60, "1h"
    end
  end

end
