
/*
  Accepts an html element's id and an arry of data.
  Uses the id to determine which graph to pupulate with
  passed in data.
*/
function renderOvertimeGraph(elm, data_source, data){
  var data_points = new Array();
  var i = 0;

  $.each(data, function(index, value){
    if(index != "serial_number"){data_points[i++] = {label: index, data: cleanSeries(value)};}
  })

  var xrange = getMinMax(data_points);

  function plotAccordingToChoices(){
    var data = [];

    $("input:checked").each(function(){
      var key = $(this).attr("name");

      if(key && data_points[key])
        data.push(data_points[key]);
    });

    if(data.length > 0)
      $.plot($(elm), data, optionsOvertime());

    var overview = $.plot($(".overview"), data, 
      $.extend(true, {}, optionsOvertime(), {
        yaxis: {min: -5, max: 100, ticks: 3}    
    }));
  }


  function rePlot(ranges){

    if(ranges.xaxis != undefined)    
      document.ranges = ranges;
  
    var data = [];

	if($("input:checked").length == 1){
		$("input:checked").attr("disabled", true);
	}else{
		$("input").attr("disabled", false);
	}

    $("input:checked").each(function(){
      var key = $(this).attr("name");

      if(key && data_points[key])
        data.push(data_points[key]);
    });

    if(isNotZoom()){
      if(data.length > 0){
        $.plot($(elm), data, 
          $.extend(true, {}, optionsOvertime(), {
          points: {show: true}, 
          xaxis: {min: xrange.min, max: xrange.max}
        }));  

        
        $.plot($(".overview"), data, 
          $.extend(true, {}, optionsOvertime(), {
   
        }));
      }
    }else{
      if(data.length > 0){
        $.plot($(elm), data, 
        $.extend(true, {}, optionsOvertime(), {
          points: {show: true},       
          xaxis: { min: document.ranges.xaxis.from, max: document.ranges.xaxis.to },
          yaxis: { min: document.ranges.yaxis.from, max: document.ranges.yaxis.to }  
        }));

      
        var overview =  $.plot($(".overview"), data, 
          $.extend(true, {}, optionsOvertime(), {
          yaxis: {ticks: 3}    
        }));
      }
      overview.setSelection(ranges, true);
    }
  }

  function showTooltip(x, y, contents){
      $('<div id="tooltip">' + contents + '</div>').css( {
          position: 'absolute',
          display: 'none',
          top: y + -5,
          left: x + 20,
          border: '1px solid #fdd',
          padding: '2px',
          'background-color': '#fee',
          opacity: 0.80
      }).appendTo("body").fadeIn(200);
    }


  function enableToolTips(){
    var tooltip = $("#tooltip_label").attr("value");
    var previousPoint = null;
    $(elm).bind("plothover", function (event, pos, item){

      $("#x").text(pos.x.toFixed(2));
      $("#y").text(pos.y.toFixed(2));

      if(item){
        if(previousPoint != item.datapoint){
          previousPoint = item.datapoint;
          $("#tooltip").remove();
          var x = item.datapoint[0].toFixed(2);
          var y = item.datapoint[1].toFixed(2);
          var d = new Date(parseInt(x));
          showTooltip(item.pageX, item.pageY,
                    parseFloat(y)) + tooltip;
        }
      }else{
        $("#tooltip").remove();
        previousPoint = null;            
      }
    });

     $(".overview").bind("plothover", function (event, pos, item){
      var tooltip = $("#tooltip_label").attr("value");
      $("#x").text(pos.x.toFixed(2));
      $("#y").text(pos.y.toFixed(2));

      if(item){
        if(previousPoint != item.datapoint){
          previousPoint = item.datapoint;
          $("#tooltip").remove();
          var x = item.datapoint[0].toFixed(2);
          var y = item.datapoint[1].toFixed(2);

          var d = new Date(parseInt(x));
          showTooltip(item.pageX, item.pageY,
                    item.series.label + " " + parseInt(y) + tooltip);
        }
      }else{
        $("#tooltip").remove();
        previousPoint = null;            
      }
    });
  }

    

  insertCheckBoxes(data_points, data_source,  rePlot);
  
  enableToolTips();
  var plot = $.plot($(elm), data_points, 
    $.extend(true, {}, optionsOvertime(), {
      points: {show: true}, 
      xaxis: {min: xrange.min, max: xrange.max}
  }));  

  var overview = $.plot($(".overview"), data_points, 
   $.extend(true, {}, optionsOvertime(), {
      yaxis: {ticks: 3}    
    }));   

  $(elm).bind("plotselected", function (event, ranges){
    if(ranges.xaxis.to - ranges.xaxis.from < 0.00001)
      ranges.xaxis.to = ranges.xaxis.from + 0.00001;
    if(ranges.yaxis.to - ranges.yaxis.from < 0.00001)
      ranges.yaxis.to = ranges.yaxis.from + 0.00001;

    rePlot(ranges);

    //don't fire event on the overview to prevent eternal loop
    overview.setSelection(ranges, true);
  });
    
  $(".overview").bind("plotselected", function (event, ranges){
    plot.setSelection(ranges);
  });

}


function isNotZoom(ranges){
  return ((document.ranges == undefined) || (document.ranges.xaxis == undefined));
}


function insertCheckBoxes(data_points, data_source,  rePlot){
  var i=0;
  var tbl = "";  
  
  if (data_points.length == 1){
    tbl = "<table style='visibility: hidden;' class='checkbox_table'>";
  }else{
    tbl = "<table class='checkbox_table'>";
    $(".choices_"+data_source).show();
  }
  
  $.each(data_points, function(key, val){
    val.color = i;
    tbl += '<tr><td class="cb'+i+'"><input name="'+i+'" type="checkbox" checked="checked" />';
    tbl +='</td><td>'+val.label+'</td></tr>';
    ++i;});
  tbl += "</table>";
  
  $(".choices_"+data_source).html(tbl);
  $("input").click(rePlot);
}



/*
  Options for the main graph 
*/
function optionsOvertime(){
    var yobj = {};
    if(document.is_percentage)
      yobj = {tickFormatter: formatToPercent, min: -5, max: 100}    

    var opts = {
    legend: { show: false },
    yaxis: yobj,
    xaxis: {mode: 'time', ticks: 3,  timeformat: "%m/%d/%y %h:%M"
 },
    selection: { mode: "xy" },
    lines: { show: true },
    grid: { backgroundColor: "#ffffff", hoverable: true, clickable: true, color: "#000000" }
    
  };
  return opts;
}







